if (FALSE) {
a <- amber.login("https://amber-demo.obiba.org")
# Find all participants
amber.participants(a)
# Find all participants for a specific participant/patient study identifier
amber.participants(a, identifier = "1231")
# Find all participants which data is equal to some value
# (will not work if the data are encrypted in the database)
amber.participants(a, query = list(data.country = "fr"))
# Find the participants of a study interview campaign
amber.participants(a, study = "Liftup", campaign = "base")
amber.logout(a)
}
Run the code above in your browser using DataLab